/* $Id: rcondefs.h,v 1.3 2012-03-10 13:08:12 simimeie Exp $
 * Definitions for remote control of the universalmainboard.
 * This file is shared between microcontroller firmware and the host software
 */

#ifndef _RCONDEFS_H_
#define _RCONDEFS_H_


/* Format of a request packet:
 * Byte   Content
 *   0    RCON_MAGIC1
 *   1    RCON_MAGIC2
 *   2    rconpassword[0]
 *   3    rconpassword[1]
 *  ..
 *  17    rconpassword[15]
 *  18    request-id high byte
 *  19    request-id low byte
 *  20    command
 *  21..  optional parameters if any (depending on command)
 */

/* Format of a reply packet:
 * Byte   Content
 *   0    RCON_MAGIC1
 *   1    RCON_MAGIC2
 *   2    request-id high byte
 *   3    request-id low byte
 *   4    reply-code
 *   5    optional reply parameters if any (depending on command)
 */

/* Identifier for packets */
#define RCON_MAGIC1   'P'
#define RCON_MAGIC2   'F'


/* Commands / Requests */
/* ping
 * no parameters.
 * returns nothing. */
#define RCON_CMD_PING           0x01
/* set brightness
 * parameters: 1 byte: new led brightness (0-7)
 * returns: 1 byte: current led brightness */
#define RCON_CMD_SETBRI         0x02
/* set display override
 * parameters: 1 byte: length of the override in 1/10th seconds
 *             6 bytes: the values for sending to the led display controller
 * returns nothing but status. */
#define RCON_CMD_SETDISPOV      0x03

#define RCON_CMD_MAX  RCON_CMD_SETDISPOV

/* Reply codes */
#define RCON_REP_ACK 23     /* Acknowledged */
#define RCON_REP_NAK 42     /* Command rejected */
#define RCON_REP_ERR 66     /* Error during command execution */

#endif /* _RCONDEFS_H_ */
