/* $Id: timers.h,v 1.3 2010-08-22 07:23:57 simimeie Exp $
 * Functions for timing.
 * This mainly allows you to get a timestamp value - a very exact one
 * (resolution 1 clock cycle) or a less exact one.
 */

#ifndef _TIMERS_H_
#define _TIMERS_H_

/* timestamps are usually delivered in 'ticks'.
 * At 12.0 MHz, there are ca. 183 ticks per second, and the 16 bit tick counter
 * overflows about every 357 seconds.
 * If you need exacter timing, you can also get a struct timestamp.
 * That will contain the tick value and the current counter value as
 * an uint16, giving you a precision of up to 1 cpu clock cycle.
 * At 12.0 MHz, the tovfls value itself overflows after around 270 days. */

#define TICKSPERSECOND (CPUFREQ / 65536UL)
#define TICKSPERSECONDF ((float)CPUFREQ / 65536.0)

struct timestamp {
  uint16_t tovfls;  /* Tick overflows - how often the ticks field has overflowed */
  uint16_t ticks;
  uint16_t partticks;
};

/* Init timers */
void timers_init(void);

/* get ticks.
 * Warning: Will reenable interrupts if they were disabled. */
uint16_t getticks(void);
/* The same, but won't touch the global interrupt enable bit.
 * MUST BE CALLED WITH INTERRUPTS DISABLED */
uint16_t getticks_noirq(void);

/* get timestamp
 * Warning: Will reenable interrupts if they were disabled. */
void gettimestamp(struct timestamp * ts);
/* The same, but won't touch the global interrupt enable bit.
 * MUST BE CALLED WITH INTERRUPTS DISABLED */
void gettimestamp_noirq(struct timestamp * ts);

#endif /* _TIMERS_H_ */
